##CH6.Tab4.Cov2.r

library(lavaan)

##Set up##
dat <- read.table(file = "grade7and8.long.823.dat", 
                col.names = c("PAT1P1","PAT1P2","PAT1P3","NAT1P1","NAT1P2","NAT1P3",
                              "PAT2P1","PAT2P2","PAT2P3","NAT2P1","NAT2P2","NAT2P3",
                              "PAT3P1","PAT3P2","PAT3P3","NAT3P1","NAT3P2","NAT3P3",
                             "grade", "female","black", "hispanic","other"))

##look at your data
#head(dat)


##Make model##
mod1 <-'
	### loadings
	Pos1 =~ L1*PAT1P1 + L2*PAT1P2 + L3*PAT1P3
	Neg1 =~ L4*NAT1P1 + L5*NAT1P2 + L6*NAT1P3
	Pos2 =~ L1*PAT2P1 + L2*PAT2P2 + L3*PAT2P3
	Neg2 =~ L4*NAT2P1 + L5*NAT2P2 + L6*NAT2P3
	Pos3 =~ L1*PAT3P1 + L2*PAT3P2 + L3*PAT3P3
	Neg3 =~ L4*NAT3P1 + L5*NAT3P2 + L6*NAT3P3
	L1 == 3 - L2 - L3
	L4 == 3 - L5 - L6
	
	FG =~ 1*grade   ## single indicator factors
	FF =~ 1*female
	FB =~ 1*black
	FH =~ 1*hispanic
	FO =~ 1*other
	


	### factor variance
	Pos1 ~~ Pos1
	Neg1 ~~ Neg1
	Pos2 ~~ Pos2
	Neg2 ~~ Neg2
	Pos3 ~~ Pos3
	Neg3 ~~ Neg3
	FG ~~ FG
	FF ~~ FF
	FB ~~ FB
	FH ~~ FH
	FO ~~ FO

	### factor covariance (some become beta)
	Pos1 ~~ Neg1 
	Pos2 ~~ Neg2 
	Pos3 ~~ Neg3
	
	FG ~~ FF + FB + FH + FO
	FF ~~ FB + FH + FO
	FB ~~ FH + FO
	FH ~~ FO
	
	### auto-regressive path
	Pos2 ~ Pos1
	Pos3 ~ Pos2 + Pos1
	
	Neg2 ~ Neg1
	Neg3 ~ Neg2 + Neg1

	### Only the last wave of constructs are regressed onto the covariates
	# Pos1 ~ FG + FF + FB + FH + FO
	# Neg1 ~ FG + FF + FB + FH + FO
	# Pos2 ~ FG + FF + FB + FH + FO
	# Neg2 ~ FG + FF + FB + FH + FO
	Pos3 ~ FG + FF + FB + FH + FO
	Neg3 ~ FG + FF + FB + FH + FO
	

	### residual variance
	PAT1P1 ~~ PAT1P1
	PAT1P2 ~~ PAT1P2
	PAT1P3 ~~ PAT1P3
	NAT1P1 ~~ NAT1P1
	NAT1P2 ~~ NAT1P2
	NAT1P3 ~~ NAT1P3
	PAT2P1 ~~ PAT2P1
	PAT2P2 ~~ PAT2P2
	PAT2P3 ~~ PAT2P3
	NAT2P1 ~~ NAT2P1
	NAT2P2 ~~ NAT2P2
	NAT2P3 ~~ NAT2P3
	PAT3P1 ~~ PAT3P1
	PAT3P2 ~~ PAT3P2
	PAT3P3 ~~ PAT3P3
	NAT3P1 ~~ NAT3P1
	NAT3P2 ~~ NAT3P2
	NAT3P3 ~~ NAT3P3
	grade ~~ 0*grade
	female ~~ 0*female
	black ~~ 0*black
	hispanic ~~ 0*hispanic
	other ~~ 0*other

	### cross-time correlated residuals
	PAT1P1 ~~ PAT2P1 + PAT3P1
	PAT2P1 ~~ PAT3P1
	PAT1P2 ~~ PAT2P2 + PAT3P2
	PAT2P2 ~~ PAT3P2
	PAT1P3 ~~ PAT2P3 + PAT3P3
	PAT2P3 ~~ PAT3P3
	NAT1P1 ~~ NAT2P1 + NAT3P1
	NAT2P1 ~~ NAT3P1
	NAT1P2 ~~ NAT2P2 + NAT3P2
	NAT2P2 ~~ NAT3P2
	NAT1P3 ~~ NAT2P3 + NAT3P3
	NAT2P3 ~~ NAT3P3

	## latent mean
	Pos1 ~ 1
	Neg1 ~ 1
	Pos2 ~ 1
	Neg2 ~ 1
	Pos3 ~ 1
	Neg3 ~ 1
	FG ~ 1
	FF ~ 1
	FB ~ 1
	FH ~ 1
	FO ~ 1

	## intercept
	PAT1P1 ~ t1*1
	PAT1P2 ~ t2*1
	PAT1P3 ~ t3*1
	NAT1P1 ~ t4*1
	NAT1P2 ~ t5*1
	NAT1P3 ~ t6*1
	PAT2P1 ~ t1*1
	PAT2P2 ~ t2*1
	PAT2P3 ~ t3*1
	NAT2P1 ~ t4*1
	NAT2P2 ~ t5*1
	NAT2P3 ~ t6*1
	PAT3P1 ~ t1*1
	PAT3P2 ~ t2*1
	PAT3P3 ~ t3*1
	NAT3P1 ~ t4*1
	NAT3P2 ~ t5*1
	NAT3P3 ~ t6*1

	t1 == 0 - t2 - t3
	t4 == 0 - t5 - t6
	
	grade ~ 0*1
	female ~ 0*1
	black ~ 0*1
	hispanic ~ 0*1
	other ~ 0*1
	'

fit1 <- lavaan(mod1, data = dat, meanstructure=T)
#### Did not converge on first run, used final estimates on starting values for next run
fit2 <- lavaan(mod1, data = dat, meanstructure=T, start = fit1)
summary(fit2, standardized=T, fit.measures=T)